@@ -51,6 +51,7 @@
 # misdata: optional. any missing values in the data? list, misdata[[q]] for each data set
 # is.na.A: optional. where are the missing values? list, is.na.A[[q]] for each data set (if misdata[[q]] == TRUE)
 # ind.NA: optional. which rows have missing values? list, ind.NA[[q]] for each data set.
+# ind.NA.col: optional. which col have missing values? list, ind.NA.col[[q]] for each data set.
 # parallel: logical.
 
 stratified.subsampling = function(Y, folds = 10)
@@ -114,6 +115,7 @@ scale,
 misdata,
 is.na.A,
 ind.NA,
+ind.NA.col,
 parallel
 )
 {    #-- checking general input parameters --------------------------------------#
@@ -233,11 +235,15 @@ parallel
                 is.na.A.test = is.na.A[omit,, drop=FALSE]
                 
                 ind.NA.train = which(apply(is.na.A.train, 1, sum) > 0) # calculated only once
-                ind.NA.test = which(apply(is.na.A.test, 1, sum) > 0) # calculated only once
+                #ind.NA.test = which(apply(is.na.A.test, 1, sum) > 0) # calculated only once
+
+                ind.NA.col.train = which(apply(is.na.A.train, 2, sum) > 0) # calculated only once
+                #ind.NA.col.test = which(apply(is.na.A.test, 2, sum) > 0) # calculated only once
 
             } else {
                 is.na.A.train = is.na.A.test =NULL
-                ind.NA.train = ind.NA.test = NULL
+                ind.NA.train = NULL
+                ind.NA.col.train = NULL
             }
             #-- split the NA in training and testing --#
             #------------------------------------------#
@@ -303,7 +309,8 @@ parallel
             keepX=choice.keepX, keepY=rep(ncol(Y.train.mat), ncomp-1), test.keepX=test.keepX, test.keepY=ncol(Y.train.mat),
             mode="regression", scale=scale, near.zero.var=near.zero.var,
             max.iter=max.iter, logratio="none", DA=TRUE, multilevel=NULL,
-            misdata = misdata, is.na.A = list(X=is.na.A.train, Y=NULL), ind.NA = list(X=ind.NA.train, Y=NULL), all.outputs=FALSE)
+            misdata = misdata, is.na.A = list(X=is.na.A.train, Y=NULL), ind.NA = list(X=ind.NA.train, Y=NULL),
+            ind.NA.col = list(X=ind.NA.col.train, Y=NULL), all.outputs=FALSE)
             
             # `result' returns loadings and variates for all test.keepX on the ncomp component
             
