@@ -380,7 +380,6 @@ cpus,
     
     #-- tells which variables are selected in X and in Y --#
 
-    #keepX.constraint = NULL
     if (any(class(object) == "splsda"))
     {
         keepX = object$keepX
@@ -491,9 +490,10 @@ cpus,
         is.na.A = is.na(X)
         
         ind.NA = which(apply(is.na.A, 1, sum) > 0) # calculated only once
+        ind.NA.col = which(apply(is.na.A, 2, sum) > 0) # calculated only once
     } else {
         is.na.A = NULL
-        ind.NA = NULL
+        ind.NA = ind.NA.col = NULL
     }
     #-- NA calculation      ----------------------------------------------------#
     #---------------------------------------------------------------------------#
@@ -563,7 +563,7 @@ cpus,
         measure = measure, dist = dist, scale=scale,
         near.zero.var = near.zero.var,
         auc = auc, progressBar = progressBar, class.object = class(object), cl = cl, parallel = parallel,
-        misdata = misdata, is.na.A = is.na.A, ind.NA = ind.NA)
+        misdata = misdata, is.na.A = is.na.A, ind.NA = ind.NA, ind.NA.col = ind.NA.col)
 
         # ---- extract stability of features ----- # NEW
         if (any(class(object) == "splsda"))
@@ -605,7 +605,6 @@ cpus,
 
     names(prediction.all) = paste('comp', 1:ncomp)
     
-    
     # calculating the number of optimal component based on t.tests and the error.rate.all, if more than 3 error.rates(repeat>3)
     ncomp_opt = matrix(NA, nrow = length(measure), ncol = length(dist),
     dimnames = list(measure, dist))
