@@ -3,7 +3,7 @@
 #   Florian Rohart, The University of Queensland, The University of Queensland Diamantina Institute, Translational Research Institute, Brisbane, QLD
 #
 # created: 27-05-2015
-# last modified: 27-05-2016
+# last modified: 05-10-2017
 #
 # Copyright (C) 2015
 #
@@ -37,10 +37,29 @@
 
 # note FR: 27/05/16: the way I dealt with missing block to predict will probably not work for mint.block analysis
 
+
+# object: any object (mint).(block).(s)pls(da)
+# newdata: data to predict, same form as what's in object$X
+# study.test: optional, used if a mint object.  grouping factor indicating which samples of `newdata' are from the same study
+# dist: prediction distance to use
+# multilevel: if there was a multilevel in object, one should be used for `newdata'
+# newdata.scale: hidden parameter. used in tune/perf functions. pass `newdata' that has been scale already (gain in computational time)
+# misdata.all: hidden parameter. used in tune/perf functions. any missing values in object$X
+# is.na.X: hidden parameter. used in tune/perf functions. where are the missing values in object$X
+# is.na.newdata: hidden parameter. used in tune/perf functions. where are the missing values in `newdata'
+# noAveragePredict: hidden parameter. used in tune/perf functions. no calculation of Average Prediction (gain in computational time)
+
+
 predict.block.pls <-predict.block.spls <- predict.mint.splsda <-
 predict.pls <-predict.spls <-
 function(object, newdata,study.test,dist = c("all", "max.dist", "centroids.dist", "mahalanobis.dist"), multilevel = NULL, ...)
 {
+    time=FALSE
+    
+    # pass R check
+    newdata.scale = misdata.all = is.na.X = is.na.newdata = noAveragePredict = NULL
+    
+    # input parameter: noAveragePredict=> no averagePredict calculation, used in tune.block.splsda
     
     if(any(class(object)%in%c("rgcca","sparse.rgcca")))
     stop("no prediction for RGCCA methods")
@@ -51,8 +70,6 @@ function(object, newdata,study.test,dist = c("all", "max.dist", "centroids.dist"
     #end general checks
     
     ncomp = object$ncomp
-    newdata.input=newdata
-    
     
     if(length(grep("plsda",class(object)))>0) # a DA analysis (mint).(block).(s)plsda
     {
@@ -69,7 +86,16 @@ function(object, newdata,study.test,dist = c("all", "max.dist", "centroids.dist"
     }
     q=ncol(Y)
     
-
+    if(time) time1 = proc.time()
+    #print(names(list(...)))
+    
+    if(hasArg(newdata.scale)) # if an input `newdata.scale' is given, we use that one and we don't scale the data and don't do the logratio or multilevel
+    {
+        newdata = list(...)$newdata.scale
+        object$logratio = NULL
+        multilevel = NULL
+    }
+    
     ### if the object is a block, the input newdata is different, we check newdata, make sure it's a list and check newdata/X
     if(length(grep("block",class(object)))==0) # not a block (pls/spls/plsda/splsda/mint...)
     {
@@ -224,161 +250,194 @@ function(object, newdata,study.test,dist = c("all", "max.dist", "centroids.dist"
     
     scale = object$scale # X and Y are both mean centered by groups and if scale=TRUE they are scaled by groups
     
-    #save(list=ls(),file="temp.Rdata")
 
     ### if the object is not a mint analysis, the input study.test is missing and we can go faster to scale the data
-    if(length(grep("mint",class(object)))==0 )#| nlevels(factor(object$study))<=1) #not a mint object or just one level in the study
-    {   # not a mint (pls/spls/plsda/splsda/block...)
+    
+    # we only scale the data if the input `newdata.scale' is missing. Only use in tune functions where we do not need to scale for every prediction as we predict on the same newdata for a grid of keepX
+    if(!hasArg(newdata.scale))
+    {
+        if(length(grep("mint",class(object)))==0 )#| nlevels(factor(object$study))<=1) #not a mint object or just one level in the study
+        {   # not a mint (pls/spls/plsda/splsda/block...)
 
-        # scale newdata if just one study
-        if (!is.null(attr(X[[1]], "scaled:center")))
-        newdata[which(!is.na(ind.match))] = lapply(which(!is.na(ind.match)), function(x){sweep(newdata[[x]], 2, STATS = attr(X[[x]], "scaled:center"))})
-        if (scale)
-        newdata[which(!is.na(ind.match))] = lapply(which(!is.na(ind.match)), function(x){sweep(newdata[[x]], 2, FUN = "/", STATS = attr(X[[x]], "scaled:scale"))})
+            # scale newdata if just one study
+            if (!is.null(attr(X[[1]], "scaled:center")))
+            newdata[which(!is.na(ind.match))] = lapply(which(!is.na(ind.match)), function(x){sweep(newdata[[x]], 2, STATS = attr(X[[x]], "scaled:center"))})
+            if (scale)
+            newdata[which(!is.na(ind.match))] = lapply(which(!is.na(ind.match)), function(x){sweep(newdata[[x]], 2, FUN = "/", STATS = attr(X[[x]], "scaled:scale"))})
 
+            means.Y = matrix(attr(Y, "scaled:center"),nrow=nrow(newdata[[1]]),ncol=q,byrow=TRUE);
+            if (scale)
+            {sigma.Y = matrix(attr(Y, "scaled:scale"),nrow=nrow(newdata[[1]]),ncol=q,byrow=TRUE)}else{sigma.Y=matrix(1,nrow=nrow(newdata[[1]]),ncol=q)}
+            concat.newdata=newdata
+            names(concat.newdata)=names(X)
+            
+        }else{
+            # a mint analysis
+            
+            #check study.test
+            if(missing(study.test))
+            {
+                if(nlevels(object$study)==1)
+                {study.test=factor(rep(1,nrow(newdata[[1]])))}else{
+                    stop("'study.test' is missing")}
+            }else{
+                study.test=as.factor(study.test)
+            }
+            if (any(unlist(lapply(newdata, nrow)) != length(study.test)))
+            stop(paste0("'study' must be a factor of length ",nrow(newdata[[1]]),"."))
+            
+            #scale newdata if more than one study. If some levels of study.test are included in study.learn, the means/sigmas of study.learn are used to scale
+            M=nlevels(study.test)
+            study.learn=factor(object$study)
+            names.study.learn=levels(study.learn);names.study.test=levels(study.test)
+            match.study=match(names.study.test,names.study.learn)
+            match.study.indice=which(!is.na(match.study))
+            
+            newdata.list.study = lapply(newdata,study_split,study.test) #a list of lists. [[j]][[m]]: j is for the blocks, m is for the levels(study)
+            
+            # each study is normalized, depending on how the normalization was performed on the learning set (center/scale)
+            newdata.list.study.scale.temp =NULL#vector("list",length=J) #list(list())
+            concat.newdata  = vector("list",length=J)
+            for(j in 1:J) # loop on the blocks
+            {
+                for (m in 1:M) #loop on the groups of study.test
+                {
+                    # case 1: sample test is part of the learning data set
+                    if(m%in%match.study.indice) #if some study of study.test were already in the learning set
+                    {
+                        
+                        if(scale==TRUE)
+                        {
+                            if(nlevels(object$study)>1)
+                            {
+                                newdata.list.study.scale.temp=scale(newdata.list.study[[j]][[m]], center = attr(X[[j]],paste0("means:", levels(study.test)[m])), scale = attr(X[[j]],paste0("sigma:", levels(study.test)[m])))
+                            }else{#if just one level in object$study, the normalisation attributes are not named the same
+                                newdata.list.study.scale.temp=scale(newdata.list.study[[j]][[m]], center = attr(X[[j]],"scaled:center"), scale = attr(X[[j]],"scaled:scale"))
+                            }
+                        }
+                        
+                        if(scale==FALSE)
+                        {
+                            if(nlevels(object$study)>1)
+                            {
+                                newdata.list.study.scale.temp=scale(newdata.list.study[[j]][[m]], center = attr(X[[j]],paste0("means:", levels(study.test)[m])),scale=FALSE)
+                            }else{#if just one level in object$study, the normalisation attributes are not named the same
+                                newdata.list.study.scale.temp=scale(newdata.list.study[[j]][[m]], center = attr(X[[j]],"scaled:center"),scale=FALSE)
+                            }
+                            
+                            
+                        }
+                        
+                    }else{
+                    # case 2: sample test is a new study # a new study which was not in the learning set
+                        newdata.list.study.scale.temp=scale(newdata.list.study[[j]][[m]],center=TRUE,scale=scale)
+                    }
+                    #concatenation of the scaled data
+                    concat.newdata[[j]] = rbind(concat.newdata[[j]], unlist(newdata.list.study.scale.temp))#[[j]][[m]]))
+                }
+            }
+            
+            # we now need to reorganise concat.newdata as newdata. Indeed, the concatenation was done without taking care of the order of the samples in newdata
+            for(j in 1:J) # loop on the blocks
+            {
+                indice.match=match(rownames(newdata[[j]]),rownames(concat.newdata[[j]]))
+                #match indice
+                concat.newdata[[j]]=concat.newdata[[j]][indice.match,]
+                concat.newdata[[j]][which(is.na(concat.newdata[[j]]))]=0 # taking care of the NA due to normalisation: put to 0 so they don't influence the product below (in Y.hat), reviens au meme que de supprimer les colonnes sans variances au depart.
+                
+            }
+            names(concat.newdata)=names(X)
+
+            means.Y=matrix(0,nrow=nrow(concat.newdata[[1]]),ncol=q)
+            sigma.Y=matrix(1,nrow=nrow(concat.newdata[[1]]),ncol=q)
+            
+            #loop on the blocks to define means.Y and sigma.Y for mint analysis
+            for(m in 1:M)
+            {
+                if(m%in%match.study.indice) #if some study of study.test were already in the learning set
+                {
+                    if(nlevels(object$study)>1)
+                    {
+                        means.Y[which(study.test%in%levels(study.learn)[match.study[m]]),]=matrix(attr(Y,paste0("means:", levels(study.test)[m])),nrow=length(which(study.test%in%levels(study.learn)[match.study[m]])),ncol=q,byrow=TRUE)
+                    }else{#if just one level in object$study, the normalisation attributes are not named the same
+                        means.Y[which(study.test%in%levels(study.learn)[match.study[m]]),]=matrix(attr(Y,"scaled:center"),nrow=length(which(study.test%in%levels(study.learn)[match.study[m]])),ncol=q,byrow=TRUE)
+                    }
+                    
+                    
+                    if(scale==TRUE)
+                    {
+                        # I want to build a vector with sigma.Y for each group
+                        if(nlevels(object$study)>1)
+                        {
+                            sigma.Y[which(study.test%in%levels(study.learn)[match.study[m]]),]=matrix(attr(Y,paste0("sigma:", levels(study.test)[m])),nrow=length(which(study.test%in%levels(study.learn)[match.study[m]])),ncol=q,byrow=TRUE)
+                        }else{#if just one level in object$study, the normalisation attributes are not named the same
+                            sigma.Y[which(study.test%in%levels(study.learn)[match.study[m]]),]=matrix(attr(Y,"scaled:scale"),nrow=length(which(study.test%in%levels(study.learn)[match.study[m]])),ncol=q,byrow=TRUE)
+                        }
+                        
+                        
+                    }
+                }
+            }
+            
+        }
+        ### end if object is a mint analysis
+    } else {
         means.Y = matrix(attr(Y, "scaled:center"),nrow=nrow(newdata[[1]]),ncol=q,byrow=TRUE);
         if (scale)
         {sigma.Y = matrix(attr(Y, "scaled:scale"),nrow=nrow(newdata[[1]]),ncol=q,byrow=TRUE)}else{sigma.Y=matrix(1,nrow=nrow(newdata[[1]]),ncol=q)}
         concat.newdata=newdata
         names(concat.newdata)=names(X)
-        
-    }else{
-        # a mint analysis
-        
-        #check study.test
-        if(missing(study.test))
-        {
-            if(nlevels(object$study)==1)
-            {study.test=factor(rep(1,nrow(newdata[[1]])))}else{
-                stop("'study.test' is missing")}
-        }else{
-            study.test=as.factor(study.test)
-        }
-        if (any(unlist(lapply(newdata, nrow)) != length(study.test)))
-        stop(paste0("'study' must be a factor of length ",nrow(newdata[[1]]),"."))
-        
-        #scale newdata if more than one study. If some levels of study.test are included in study.learn, the means/sigmas of study.learn are used to scale
-        M=nlevels(study.test)
-        study.learn=factor(object$study)
-        names.study.learn=levels(study.learn);names.study.test=levels(study.test)
-        match.study=match(names.study.test,names.study.learn)
-        match.study.indice=which(!is.na(match.study))
-        
-        newdata.list.study = lapply(newdata,study_split,study.test) #a list of lists. [[j]][[m]]: j is for the blocks, m is for the levels(study)
-        
-        # each study is normalized, depending on how the normalization was performed on the learning set (center/scale)
-        newdata.list.study.scale.temp =NULL#vector("list",length=J) #list(list())
-        concat.newdata  = vector("list",length=J)
-        for(j in 1:J) # loop on the blocks
-        {
-            for (m in 1:M) #loop on the groups of study.test
-            {
-                # case 1: sample test is part of the learning data set
-                if(m%in%match.study.indice) #if some study of study.test were already in the learning set
-                {
-                    
-                    if(scale==TRUE)
-                    {
-                        if(nlevels(object$study)>1)
-                        {
-                            newdata.list.study.scale.temp=scale(newdata.list.study[[j]][[m]], center = attr(X[[j]],paste0("means:", levels(study.test)[m])), scale = attr(X[[j]],paste0("sigma:", levels(study.test)[m])))
-                        }else{#if just one level in object$study, the normalisation attributes are not named the same
-                            newdata.list.study.scale.temp=scale(newdata.list.study[[j]][[m]], center = attr(X[[j]],"scaled:center"), scale = attr(X[[j]],"scaled:scale"))
-                        }
-                    }
-                    
-                    if(scale==FALSE)
-                    {
-                        if(nlevels(object$study)>1)
-                        {
-                            newdata.list.study.scale.temp=scale(newdata.list.study[[j]][[m]], center = attr(X[[j]],paste0("means:", levels(study.test)[m])),scale=FALSE)
-                        }else{#if just one level in object$study, the normalisation attributes are not named the same
-                            newdata.list.study.scale.temp=scale(newdata.list.study[[j]][[m]], center = attr(X[[j]],"scaled:center"),scale=FALSE)
-                        }
-                        
-                        
-                    }
-                    
-                }else{
-                # case 2: sample test is a new study # a new study which was not in the learning set
-                    newdata.list.study.scale.temp=scale(newdata.list.study[[j]][[m]],center=TRUE,scale=scale)
-                }
-                #concatenation of the scaled data
-                concat.newdata[[j]] = rbind(concat.newdata[[j]], unlist(newdata.list.study.scale.temp))#[[j]][[m]]))
-            }
-        }
-        
-        # we now need to reorganise concat.newdata as newdata. Indeed, the concatenation was done without taking care of the order of the samples in newdata
-        for(j in 1:J) # loop on the blocks
-        {
-            indice.match=match(rownames(newdata[[j]]),rownames(concat.newdata[[j]]))
-            #match indice
-            concat.newdata[[j]]=concat.newdata[[j]][indice.match,]
-            concat.newdata[[j]][which(is.na(concat.newdata[[j]]))]=0 # taking care of the NA due to normalisation: put to 0 so they don't influence the product below (in Y.hat), reviens au meme que de supprimer les colonnes sans variances au depart.
-            
-        }
-        names(concat.newdata)=names(X)
-
-        means.Y=matrix(0,nrow=nrow(concat.newdata[[1]]),ncol=q)
-        sigma.Y=matrix(1,nrow=nrow(concat.newdata[[1]]),ncol=q)
-        
-        #loop on the blocks to define means.Y and sigma.Y for mint analysis
-        for(m in 1:M)
-        {
-            if(m%in%match.study.indice) #if some study of study.test were already in the learning set
-            {
-                if(nlevels(object$study)>1)
-                {
-                    means.Y[which(study.test%in%levels(study.learn)[match.study[m]]),]=matrix(attr(Y,paste0("means:", levels(study.test)[m])),nrow=length(which(study.test%in%levels(study.learn)[match.study[m]])),ncol=q,byrow=TRUE)
-                }else{#if just one level in object$study, the normalisation attributes are not named the same
-                    means.Y[which(study.test%in%levels(study.learn)[match.study[m]]),]=matrix(attr(Y,"scaled:center"),nrow=length(which(study.test%in%levels(study.learn)[match.study[m]])),ncol=q,byrow=TRUE)
-                }
-                
-                
-                if(scale==TRUE)
-                {
-                    # I want to build a vector with sigma.Y for each group
-                    if(nlevels(object$study)>1)
-                    {
-                        sigma.Y[which(study.test%in%levels(study.learn)[match.study[m]]),]=matrix(attr(Y,paste0("sigma:", levels(study.test)[m])),nrow=length(which(study.test%in%levels(study.learn)[match.study[m]])),ncol=q,byrow=TRUE)
-                    }else{#if just one level in object$study, the normalisation attributes are not named the same
-                        sigma.Y[which(study.test%in%levels(study.learn)[match.study[m]]),]=matrix(attr(Y,"scaled:scale"),nrow=length(which(study.test%in%levels(study.learn)[match.study[m]])),ncol=q,byrow=TRUE)
-                    }
-                    
-                    
-                }
-            }
-        }
-        
     }
-    ### end if object is a mint analysis
+    if(time) time2 = proc.time()
+    if(time) print("scaling")
+    if(time) print(time2-time1)
+    
     
     ### at this stage we have
     # X         # list of blocks
     # Y         # observation
     # newdata   #list of blocks for the prediction, same length as A, scaled
     
-    # replace NA by 0
-    concat.newdata = lapply(concat.newdata,function(x)
-    {
-        ind = which(is.na(x))
-        if (length(ind) > 0)
-        x[ind] = 0
-        x
-    })
     
-    # replace NA by 0
-    X = lapply(X,function(x)
+    ###  replace NA by 0 in the training data
+    
+    if( (hasArg(misdata.all) & hasArg(is.na.X)) && list(...)$misdata.all) # ind.na.X: all blocks except Y
+    {    # if misdata.all and ind.na.X are provided, we don't calculate the is.na(X) as it takes time. Used in tune functions.
+        X = lapply(1:J, function(q){replace(X[[q]], list(...)$is.na.X[[q]], 0)})
+    } else {
+        # replace NA by 0
+        X = lapply(X,function(x)
+        {
+            ind = which(is.na(x))
+            if (length(ind) > 0)
+            x[ind] = 0
+            x
+        })
+    }
+
+    if( (hasArg(misdata.all) & hasArg(is.na.newdata)) && list(...)$misdata.all) # ind.na.newdata: all blocks of newdata
     {
-        ind = which(is.na(x))
-        if (length(ind) > 0)
-        x[ind] = 0
-        x
-    })
+        # if misdata.all and ind.na.X are provided, we don't calculate the is.na(X) as it takes time. Used in tune functions.
+        concat.newdata = lapply(1:J, function(q){replace(concat.newdata[[q]], list(...)$is.na.newdata[[q]], 0)})
+    } else {
+        # replace NA by 0
+        concat.newdata = lapply(concat.newdata,function(x)
+        {
+            ind = which(is.na(x))
+            if (length(ind) > 0)
+            x[ind] = 0
+            x
+        })
+
+    }
     
     # replace NA by 0 in Y
     Y[is.na(Y)] = 0
     
+    if(time) time3 = proc.time()
+    if(time) print("NA")
+    if(time) print(time3-time2)
+    
     # -----------------------
     #       prediction
     # -----------------------
@@ -419,11 +478,14 @@ function(object, newdata,study.test,dist = c("all", "max.dist", "centroids.dist"
 
     }
     
-
+    if(time) time4 = proc.time()
+    if(time) print("Prediction")
+    if(time) print(time4-time3)
+    
     #-- valeurs sortantes --#
     names(Y.hat)=names(t.pred)=names(B.hat)=names(object$X)
 
-    
+    if(time) time4 = proc.time()
 
     # basic prediction results
     if(length(grep("block",class(object)))!=0 & length(object$X)>1 )
@@ -442,19 +504,22 @@ function(object, newdata,study.test,dist = c("all", "max.dist", "centroids.dist"
         }
         names(temp.all) = paste("dim", c(1:min(ncomp[-object$indY])), sep = " ")
         
-        out$AveragedPredict = array(unlist(lapply(temp.all, function(x){apply(x, c(1,2), mean)})), dim(Y.hat[[1]]), dimnames = list(rownames(newdata[[1]]), colnames(Y), paste("dim", c(1:min(ncomp[-object$indY])), sep = " ")))
-        
-        out$WeightedPredict = array(unlist(lapply(temp.all, function(x){apply(x, c(1,2), function(z){
-            temp = aggregate(object$weights,list(z),sum)
-            ind = which(temp[,2]== max (temp[,2]))# if two max, then NA
-            if(length(ind) == 1)
-            {
-                res = temp[ind, 1]
-            } else {
-                res = NA
-            }
-            res
-        })})), dim(Y.hat[[1]]), dimnames = list(rownames(newdata[[1]]), colnames(Y), paste("dim", c(1:min(ncomp[-object$indY])), sep = " ")))
+        if(!hasArg(noAveragePredict))
+        {
+            out$AveragedPredict = array(unlist(lapply(temp.all, function(x){apply(x, c(1,2), mean)})), dim(Y.hat[[1]]), dimnames = list(rownames(newdata[[1]]), colnames(Y), paste("dim", c(1:min(ncomp[-object$indY])), sep = " ")))
+            
+            out$WeightedPredict = array(unlist(lapply(temp.all, function(x){apply(x, c(1,2), function(z){
+                temp = aggregate(object$weights,list(z),sum)
+                ind = which(temp[,2]== max (temp[,2]))# if two max, then NA
+                if(length(ind) == 1)
+                {
+                    res = temp[ind, 1]
+                } else {
+                    res = NA
+                }
+                res
+            })})), dim(Y.hat[[1]]), dimnames = list(rownames(newdata[[1]]), colnames(Y), paste("dim", c(1:min(ncomp[-object$indY])), sep = " ")))
+        }
 
 
         #out$newdata=concat.newdata
@@ -464,37 +529,43 @@ function(object, newdata,study.test,dist = c("all", "max.dist", "centroids.dist"
     } else {# not a block (pls/spls/plsda/splsda/mint...)
         out=list(predict=Y.hat[[1]],variates=t.pred[[1]],B.hat=B.hat[[1]])
     }
+    
+    if(time) time5 = proc.time()
+    if(time) print("Y.hat")
+    if(time) print(time5-time4)
 
+    
     # get the classification for each new sample if the object is a DA
     if(any(class(object)=="DA")) # a DA analysis (mint).(block).(s)plsda
     {
         
         if(length(grep("block",class(object)))!=0 & length(object$X)>1 )
         {
-
-            # predict class of AveragePredict, only with max.dist
-            out$AveragedPredict.class$max.dist = matrix(sapply(1:ncomp[1], ### List level
-                function(y){apply(out$AveragedPredict[, , y, drop = FALSE], 1,  ### component level
+            if(!hasArg(noAveragePredict))
+            {
+                # predict class of AveragePredict, only with max.dist
+                out$AveragedPredict.class$max.dist = matrix(sapply(1:ncomp[1], ### List level
+                    function(y){apply(out$AveragedPredict[, , y, drop = FALSE], 1,  ### component level
+                        function(z){
+                            paste(levels(Y.factor)[which(z == max(z))], collapse = "/")
+                        }) ### matrix level
+                    }), nrow = nrow(newdata[[1]]), ncol = ncomp[1])
+                
+                
+                # predict class of WeightedPredict, only with max.dist
+                out$WeightedPredict.class$max.dist = matrix(sapply(1:ncomp[1], ### List level
+                function(y){apply(out$WeightedPredict[, , y, drop = FALSE], 1,  ### component level
                     function(z){
                         paste(levels(Y.factor)[which(z == max(z))], collapse = "/")
                     }) ### matrix level
                 }), nrow = nrow(newdata[[1]]), ncol = ncomp[1])
-            
-            
-            # predict class of WeightedPredict, only with max.dist
-            out$WeightedPredict.class$max.dist = matrix(sapply(1:ncomp[1], ### List level
-            function(y){apply(out$WeightedPredict[, , y, drop = FALSE], 1,  ### component level
-                function(z){
-                    paste(levels(Y.factor)[which(z == max(z))], collapse = "/")
-                }) ### matrix level
-            }), nrow = nrow(newdata[[1]]), ncol = ncomp[1])
-            
-            rownames(out$AveragedPredict.class$max.dist) = rownames(out$WeightedPredict.class$max.dist) = rownames(newdata[[1]])
-            colnames(out$AveragedPredict.class$max.dist) = colnames(out$WeightedPredict.class$max.dist) = paste("dim", c(1:min(ncomp[-object$indY])), sep = " ")
+                
+                rownames(out$AveragedPredict.class$max.dist) = rownames(out$WeightedPredict.class$max.dist) = rownames(newdata[[1]])
+                colnames(out$AveragedPredict.class$max.dist) = colnames(out$WeightedPredict.class$max.dist) = paste("dim", c(1:min(ncomp[-object$indY])), sep = " ")
+            }
         }
         
-        
-        
+
         # creating temporary 'blocks' outputs to pass into the internal_predict.DA function
         out.temp=list(predict=Y.hat[which(!is.na(ind.match))],variates=t.pred[which(!is.na(ind.match))],B.hat=B.hat[which(!is.na(ind.match))])
         out.temp$newdata=concat.newdata[which(!is.na(ind.match))]
@@ -503,11 +574,16 @@ function(object, newdata,study.test,dist = c("all", "max.dist", "centroids.dist"
         object.temp = object
         object.temp$X = object.temp$X[which(!is.na(ind.match))]
         object.temp$variates = object.temp$variates[c(which(!is.na(ind.match)),J+1)] #J+1 is Y
+        
         classif.DA=internal_predict.DA(object=object.temp, q=q, out=out.temp, dist=dist, weights = object$weights[which(!is.na(ind.match))])
         out=c(out,classif.DA)
         
     }
     
+    if(time) time6 = proc.time()
+    if(time) print("DA")
+    if(time) print(time6-time5)
+    
     out$call = match.call()
     class(out) = paste("predict")
 
