@@ -219,16 +219,18 @@ name.save = NULL)
     
     misdata = c(sapply(X,anyNA), Y=FALSE) # Detection of missing data. we assume no missing values in the factor Y
     
-    is.na.A = ind.NA = vector("list", length = length(X))
+    is.na.A = ind.NA = ind.NA.col = vector("list", length = length(X))
     for(q in 1:length(X))
     {
         if(misdata[q])
         {
             is.na.A[[q]] = is.na(X[[q]])
             ind.NA[[q]] = which(apply(is.na.A, 1, sum) > 0) # calculated only once
+            ind.NA.col[[q]] = which(apply(is.na.A[[q]], 2, sum) >0) # indice of the col that have missing values. used in the deflation
         } else {
             is.na.A[[q]] = NULL
             ind.NA[[q]] = NULL
+            ind.NA.col[[q]] = NULL
         }
     }
 
@@ -314,7 +316,7 @@ name.save = NULL)
         choice.keepX = already.tested.X, scheme = scheme, design=design, init=init, tol=tol,
         test.keepX = test.keepX, measure = measure, dist = dist, scale=scale, weighted=weighted,
         near.zero.var = near.zero.var, progressBar = progressBar, max.iter = max.iter, cl = cl,
-        misdata = misdata, is.na.A = is.na.A, ind.NA = ind.NA, parallel = parallel)
+        misdata = misdata, is.na.A = is.na.A, ind.NA = ind.NA, ind.NA.col = ind.NA.col, parallel = parallel)
         
         #returns error.rate for all test.keepX
     
